(mission)=
# Mission

```{epigraph}
The core mission of xDEM is to be **easy-of-use**, **modular** and **robust**.

It also attempts to be as **efficient**, **scalable** and **state-of-the-art** as possible.

Finally, as an open source package, it aspires to foster **reproducibility** and **open science**.
```

In details, those mean:

- **Ease-of-use:** all basic operations or methods from published works should only require a few lines of code to be performed;

- **Modularity:** all methods should be fully customizable, to allow both flexibility and inter-comparison;

- **Robustness:** all methods should be tested within our continuous integration test-suite, to enforce that they always perform as expected;

```{note}
:class: margin
**Scalability** is currently being improved towards a first major release ``v1.0``.
```

And, additionally:

- **Efficiency**: all methods should be optimized at the lower-level, to function with the highest performance offered by Python packages;

- **Scalability**: all methods should support both lazy processing and distributed parallelized processing, to work with high-resolution data on local machines as well as on HPCs;

- **State-of-the-art**: all methods should be at the cutting edge of remote sensing science, to provide users with the most reliable and up-to-date tools.

And finally:

- **Reproducibility:** all code should be version-controlled and release-based, to ensure consistency of dependent
  packages and works;

- **Open-source:** all code should be accessible and reusable to anyone in the community, for transparency and open governance.
